@@ -74,6 +74,8 @@ extern void xmtrcv_cb(Fl_Widget *, void *);
 
 static int tx_timeout = 0;
 
+static int macro_time = -1;
+
 void kill_tx(void *)
 {
 	wf->xmtrcv->value(0);
@@ -102,16 +104,50 @@ void stop_deadman()
 	tx_timeout = 0;
 }
 
+void start_macro_time()
+{
+//	std::cout << "RESET MACRO TIME" << std::endl;
+	macro_time = 0;
+}
+
+int stop_macro_time()
+{
+//	std::cout << "STOP MACRO TIME @ " << macro_time << std::endl;
+	return macro_time;
+}
+
+const timeval tmval(void)
+{
+	struct timeval t1;
+	{
+		guard_lock lk(&time_mutex);
+		gettimeofday(&t1, NULL);
+	}
+	return t1;
+}
+
+const double zusec(void)
+{
+	struct timeval t1;
+	{
+		guard_lock lk(&time_mutex);
+		gettimeofday(&t1, NULL);
+	}
+	double usecs = t1.tv_sec * 1000000L;
+	usecs += t1.tv_usec;
+	return usecs;
+}
 
 const unsigned long zmsec(void)
 {
 	struct timeval t1;
 	{
 		guard_lock lk(&time_mutex);
-		t1 = now_val;
+		gettimeofday(&t1, NULL);
 	}
-	unsigned long msecs = (t1.tv_sec % 10000) * 1000;
-	msecs += t1.tv_usec * 1000;
+	unsigned long msecs = t1.tv_sec * 1000000L;
+	msecs += t1.tv_usec;
+	msecs /= 1000L;
 	return msecs;
 }
 
@@ -178,6 +214,7 @@ void update_tx_timer()
 	tx_last_val = now_val;
 	show_tx_timer();
 	service_deadman();
+	macro_time++;
 }
 
 //void ztimer(void *)
