@@ -31,7 +31,8 @@
 #include "morse.h"
 #include "ascii.h"
 
-#define	OUTBUFSIZE	16384
+#define	OUTBUFSIZE	65536  // needed for 5 WPM Farsnworth CW buffers
+
 // Constants for signal searching & s/n threshold
 #define SIGSEARCH 5
 
@@ -55,6 +56,8 @@ protected:
 	int		samplerate;
 	bool	reverse;
 	int		sigsearch;
+	bool	sig_start;
+	bool	sig_stop;
 
 	double	bandwidth;
 	double	freqerr;
@@ -98,7 +101,7 @@ protected:
 	bool CW_EOT;
 public:
 	modem();
-	virtual ~modem(){};
+	virtual ~modem(){}
 
 // these processes must be declared in the derived class
 	virtual void init();
