@@ -24,6 +24,10 @@
 
 #include <config.h>
 
+//++++++++++++++++++
+#include <FL/Fl_Scroll.H>
+extern Fl_Scroll       *wefax_pic_rx_scroll;
+
 #include <iostream>
 #include <iomanip>
 #include <sstream>
@@ -189,7 +193,6 @@ FILE	*client;
 bool	mailserver = false, mailclient = false, arqmode = false;
 static bool show_cpucheck = false;
 static bool iconified = false;
-bool	bMOREINFO = false;
 
 string option_help, version_text, build_text;
 
@@ -1421,12 +1424,6 @@ void generate_option_help(void) {
 		 << "  --debug-level LEVEL\n"
 		 << "    Set the event log verbosity\n\n"
 
-		 << "  --debug-pskmail\n"
-		 << "    Enable logging for pskmail / arq events\n\n"
-
-		 << "  --debug-audio\n"
-		 << "    Enable logging for sound-card events\n\n"
-
 		 << "  --version\n"
 		 << "    Print version information\n\n"
 
@@ -1530,8 +1527,7 @@ int parse_args(int argc, char **argv, int& idx)
 #if USE_PORTAUDIO
 			   OPT_FRAMES_PER_BUFFER,
 #endif
-		   OPT_MORE_INFO,
-		   OPT_DEBUG_LEVEL, OPT_DEBUG_PSKMAIL, OPT_DEBUG_AUDIO,
+		   OPT_DEBUG_LEVEL,
 			   OPT_EXIT_AFTER,
 			   OPT_DEPRECATED, OPT_HELP, OPT_VERSION, OPT_BUILD_INFO };
 
@@ -1590,12 +1586,9 @@ int parse_args(int argc, char **argv, int& idx)
 #if USE_PORTAUDIO
 		{ "frames-per-buffer",1, 0, OPT_FRAMES_PER_BUFFER },
 #endif
-		{ "more-info",     1, 0, OPT_MORE_INFO },
 		{ "exit-after",    1, 0, OPT_EXIT_AFTER },
 
 		{ "debug-level",   1, 0, OPT_DEBUG_LEVEL },
-		{ "debug-pskmail", 0, 0, OPT_DEBUG_PSKMAIL },
-		{ "debug-audio", 0, 0, OPT_DEBUG_AUDIO },
 
 		{ "help",	   0, 0, OPT_HELP },
 		{ "version",	   0, 0, OPT_VERSION },
@@ -1811,10 +1804,6 @@ int parse_args(int argc, char **argv, int& idx)
 			break;
 #endif // USE_PORTAUDIO
 
-		case OPT_MORE_INFO:
-			bMOREINFO = true;
-			break;
-
 		case OPT_EXIT_AFTER:
 			Fl::add_timeout(strtod(optarg, 0), exit_cb);
 			break;
@@ -1838,14 +1827,6 @@ int parse_args(int argc, char **argv, int& idx)
 		}
 			break;
 
-		case OPT_DEBUG_PSKMAIL:
-			debug_pskmail = true;
-			break;
-
-		case OPT_DEBUG_AUDIO:
-			debug_audio = true;
-			break;
-
 		case OPT_DEPRECATED:
 			cerr << "W: the --" << longopts[longindex].name
 				 << " option has been deprecated and will be removed in a future version\n";
