@@ -47,7 +47,7 @@
 #include "status.h"
 #include "icons.h"
 
-LOG_FILE_SOURCE(debug::debug::LOG_XMLRPC_RIG);
+LOG_FILE_SOURCE(debug::debug::LOG_RPC_CLIENT);
 
 using namespace XmlRpc;
 using namespace std;
@@ -494,7 +494,6 @@ void xmlrpc_rig_post_bw(void *)
 		qso_opBW->value(posted_bw);//.c_str());
 		qso_opBW->redraw();
 		LOG_VERBOSE("Update BW %s", posted_bw.c_str());
-std::cout << "Update BW " << posted_bw << std::endl;
 	}
 	qso_opBW->show();
 }
