@@ -191,18 +191,18 @@ void trx_xmit_wfall_queue(int samplerate, const double* buf, size_t len)
 	if (unlikely(wv[0].len + wv[1].len < len)) // not enough space
 		return;
 
-#define write_(vec_, len_)					\
-	for (size_t i = 0; i < len_; i++)			\
-		vec_[i] = buf[i] * progdefaults.TxMonitorLevel;
-
 	size_t n = MIN(wv[0].len, len);
-	write_(wv[0].buf, n);
-	if (len > n) { // write the rest to the second vector
+
+	for (size_t i = 0; i < n; i++)
+		wv[0].buf[i] = buf[i] * progdefaults.TxMonitorLevel;
+
+	if (len > n) { // write the remainder to the second vector
 		buf += n;
 		n = len - n;
-		write_(wv[1].buf, n);
+		for (size_t i = 0; i < n; i++)
+			wv[1].buf[i] = buf[i] * progdefaults.TxMonitorLevel;
+
 	}
-#undef write_
 
 	trxrb.write_advance(len);
 	if (trxrb.read_space() >= WFBLOCKSIZE)
@@ -306,9 +306,6 @@ void trx_trx_receive_loop()
 		if (trx_state != STATE_RX)
 			break;
 
-		if (trx_inhibit)
-			continue;
-
 		if (bHighSpeed) {
 			bool afc = progStatus.afconoff;
 			progStatus.afconoff = false;
@@ -323,11 +320,11 @@ void trx_trx_receive_loop()
 		} else {
 			trxrb.write_advance(numread);
 			wf->sig_data(rbvec[0].buf, current_RXsamplerate);
-			REQ(&waterfall::handle_sig_data, wf);
+			if (!trx_inhibit)
+				REQ(&waterfall::handle_sig_data, wf);
 			if (!bHistory) {
 				if (fft_modem && spectrum_viewer->visible())
 					fft_modem->rx_process(rbvec[0].buf, numread);
-
 				active_modem->rx_process(rbvec[0].buf, numread);
 
 				if (audio_alert)
@@ -511,10 +508,15 @@ void trx_tune_loop()
 			if (active_modem->get_mode() == MODE_CW && 
 				(use_nanoIO ||
 				 progStatus.WK_online || 
+				 progdefaults.CW_KEYLINE_on_cat_port ||
 				 CW_KEYLINE_isopen)) {
-					if (CW_KEYLINE_isopen) active_modem->CW_KEYLINE(1);
-					else if (use_nanoIO) nanoCW_tune(1);
+					if (CW_KEYLINE_isopen || progdefaults.CW_KEYLINE_on_cat_port)
+						active_modem->CW_KEYLINE(1);
+					else if (use_nanoIO)
+						nanoCW_tune(1);
 					else WK_tune(1);
+					cwio_ptt(1);
+					cwio_key(1);
 
 					REQ(&waterfall::set_XmtRcvBtn, wf, true);
 					while (trx_state == STATE_TUNE) MilliSleep(10);
@@ -522,6 +524,8 @@ void trx_tune_loop()
 					if (CW_KEYLINE_isopen) active_modem->CW_KEYLINE(0);
 					else if (use_nanoIO) nanoCW_tune(0);
 					else WK_tune(0);
+					cwio_key(0);
+					cwio_ptt(0);
 			} else {
 				while (trx_state == STATE_TUNE) {
 					if (_trx_tune == 0) {
